@@ -112,13 +112,14 @@ const FontMetrics* TFMFont::getMetrics () const {
 		try {
 			_metrics = FontMetrics::read(_fontname);
 			if (!_metrics) {
-				_metrics = util::make_unique<NullFontMetric>();
+				_metrics = util::make_unique<NullFontMetrics>();
 				Message::wstream(true) << "can't find "+_fontname+".tfm\n";
 			}
 		}
 		catch (FontMetricException &e) {
-			_metrics = util::make_unique<NullFontMetric>();
-			Message::wstream(true) << e.what() << " in " << _fontname << ".tfm\n";
+			const char *ext = (_metrics && _metrics->isOFM()) ? ".ofm" : ".tfm";
+			_metrics = util::make_unique<NullFontMetrics>();
+			Message::wstream(true) << e.what() << " in " << _fontname << ext << "\n";
 		}
 	}
 	return _metrics.get();
