@@ -21,13 +21,7 @@
 #ifndef MD5HASHFUNCTION_HPP
 #define MD5HASHFUNCTION_HPP
 
-#include <config.h>
-#ifdef HAVE_OPENSSL_MD5_H
-#	include <openssl/md5.h>
-#else
-#	include <md5.h>
-#endif
-
+#include <md5.h>
 #include "HashFunction.hpp"
 
 class MD5HashFunction : public HashFunction {
