@@ -27,6 +27,9 @@
 
 using namespace std;
 
+bool SVGElement::USE_CURRENTCOLOR=false;
+Color SVGElement::CURRENTCOLOR;
+
 
 void SVGElement::setClipPathUrl (const string &url) {
 	if (!url.empty())
@@ -41,7 +44,9 @@ void SVGElement::setClipRule (FillRule rule) {
 
 
 void SVGElement::setFillColor (Color color, bool skipBlack) {
-	if (color != Color::BLACK || !skipBlack)
+	if (USE_CURRENTCOLOR && color == CURRENTCOLOR)
+		addAttribute("fill", "currentColor");
+	else if (color != Color::BLACK || !skipBlack)
 		addAttribute("fill", color.svgColorString());
 }
 
@@ -108,7 +113,7 @@ void SVGElement::setPoints (const vector<DPair> &points) {
 
 
 void SVGElement::setStrokeColor (Color color) {
-	addAttribute("stroke", color.svgColorString());
+	addAttribute("stroke", USE_CURRENTCOLOR && color == CURRENTCOLOR ? "currentColor" : color.svgColorString());
 }
 
 
