@@ -2,7 +2,7 @@
 ** SVGOptimizer.cpp                                                     **
 **                                                                      **
 ** This file is part of dvisvgm -- a fast DVI to SVG converter          **
-** Copyright (C) 2005-2022 Martin Gieseking <martin.gieseking@uos.de>   **
+** Copyright (C) 2005-2023 Martin Gieseking <martin.gieseking@uos.de>   **
 **                                                                      **
 ** This program is free software; you can redistribute it and/or        **
 ** modify it under the terms of the GNU General Public License as       **
@@ -25,6 +25,7 @@
 #include "../SVGTree.hpp"
 
 #include "AttributeExtractor.hpp"
+#include "ClipPathReassigner.hpp"
 #include "GroupCollapser.hpp"
 #include "RedundantElementRemover.hpp"
 #include "TextSimplifier.hpp"
@@ -38,11 +39,12 @@ string SVGOptimizer::MODULE_SEQUENCE;
 SVGOptimizer::SVGOptimizer (SVGTree *svg) : _svg(svg) {
 	// optimizer modules available to the user; must be listed in default order
 //	_moduleEntries.emplace_back(ModuleEntry("remove-ws", util::make_unique<WSNodeRemover>()));
-	_moduleEntries.emplace_back(ModuleEntry("simplify-text", util::make_unique<TextSimplifier>()));
-	_moduleEntries.emplace_back(ModuleEntry("simplify-transform", util::make_unique<TransformSimplifier>()));
-	_moduleEntries.emplace_back(ModuleEntry("group-attributes", util::make_unique<AttributeExtractor>()));
-	_moduleEntries.emplace_back(ModuleEntry("collapse-groups", util::make_unique<GroupCollapser>()));
-	_moduleEntries.emplace_back(ModuleEntry("remove-clippath", util::make_unique<RedundantElementRemover>()));
+	_moduleEntries.emplace_back("simplify-text", util::make_unique<TextSimplifier>());
+	_moduleEntries.emplace_back("simplify-transform", util::make_unique<TransformSimplifier>());
+	_moduleEntries.emplace_back("group-attributes", util::make_unique<AttributeExtractor>());
+	_moduleEntries.emplace_back("collapse-groups", util::make_unique<GroupCollapser>());
+	_moduleEntries.emplace_back("remove-clippaths", util::make_unique<RedundantElementRemover>());
+	_moduleEntries.emplace_back("reassign-clippaths", util::make_unique<ClipPathReassigner>());
 }
 
 
